@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play the tabla!
 
-our $VERSION = '0.0601';
+our $VERSION = '0.0602';
 
 use Moo;
 use File::ShareDir qw(dist_dir);
@@ -159,7 +159,7 @@ Music::Percussion::Tabla - Play the tabla!
 
 =head1 VERSION
 
-version 0.0601
+version 0.0602
 
 =head1 SYNOPSIS
 
@@ -231,8 +231,8 @@ Here are my "non-tabla player" descriptions of the sounds:
   29  88  ringing mid
   ...
 
-To play patches by number (for the unknown bols, for instance), do
-this to add to the C<84>th MIDInum entry score:
+To play patches by number (e.g. for unknown bols), do this to add the
+C<84>th MIDInum entry score:
 
   $tabla->note($tabla->eighth, 84);
 
@@ -302,13 +302,15 @@ Double strike bols:
 Play a double-strike on the B<baya> and B<daya> drums for the given
 B<bol> and B<duration>.
 
-Patches given for double-strikes will be ignored. That is, if the
-individual bols comprising the double-strike have more than one
-possible patch, one is chosen at random. If specific patches are
-desired, use the C<note> method with multiple patches.
+Patches given for double-strikes will be ignored. That is, each of the
+individual bols comprising the double-strike are chosen at random. If
+specific patches are desired, use the C<note> method with multiple
+patches.
 
 =head2 thekas
 
+Traditional "groove patterns":
+
 =over
 
 =item teentaal([$duration])
@@ -331,6 +333,8 @@ L<Moo>
 
 L<File::ShareDir>
 
+L<List::Util>
+
 L<https://gleitz.github.io/midi-js-soundfonts/Tabla/Tabla.sf2> (4.1MB)
 
 L<https://www.wikihow.com/Play-Tabla>
